#ifndef INTERNETACCESSGUI_H
#define INTERNETACCESSGUI_H

#include <QtGui/QDialog>
#include <QtCore/QString>
#include "mobilehotspotconfiguration.h"
#include "ui_internetaccessgui.h"

class InternetAccessGUI : public QDialog
{
    Q_OBJECT

public:
    InternetAccessGUI(QWidget *parent = 0);
    ~InternetAccessGUI();
    void setConfiguration(MobileHotspotConfiguration &configuration);
    void configuration(MobileHotspotConfiguration *configuration);

private:
    Ui::InternetAccessGUIClass ui;
    QString validNetwork();

};

#endif // INTERNETACCESSGUI_H
